|CI| |docs| |cov| |code-quality|

geonum: a python library for geo-numerical calculations
=========================================================

All you need to know: https://geonum.readthedocs.io/en/latest/

.. |CI| image:: https://github.com/jgliss/geonum/actions/workflows/CI.yml/badge.svg
    :target: https://github.com/jgliss/geonum/actions/

.. |docs| image:: https://readthedocs.org/projects/geonum/badge/?version=latest
    :target: https://geonum.readthedocs.io/en/latest/?badge=latest

.. |cov| image:: https://codecov.io/gh/jgliss/geonum/branch/main-dev/graph/badge.svg?token=802DAZA1W9
    :target: https://codecov.io/gh/jgliss/geonum

.. |code-quality| image:: https://www.codefactor.io/repository/github/jgliss/geonum/badge
   :target: https://www.codefactor.io/repository/github/jgliss/geonum
   :alt: Code quality